@@ -54,12 +54,13 @@ def get_log(date, which="completed", download=True, update=False, **kwargs):
         download_log(date, which=which, store=True, **kwargs)
     
     logdf = get_local_log(date, which=which, safeout=True)
+
     if logdf is None:
         if update:
-            warnings.warn(f"Download did not seem successful. Cannot retreive the {which}_log for {date}")
+            warnings.warn(f"Download did not seem successful. Cannot retrieve the {which}_log for {date}")
             return None
         elif not download:
-            warnings.warn(f"No local {which}_log for {date}. download it or set download to true")
+            warnings.warn(f"No local {which}_log for {date}. Download it or set download to true")
             return None
         
         return get_log(date, which=which, update=True, **kwargs)
@@ -179,13 +180,19 @@ def download_completed_log(date, auth=None, store=True,
         
     if verbose:
         print(logtable)
-        
+
+    d = date.split("-")
+    message_missing = f"Log queue.{d[0]}{d[1]}{d[2]}.dat does not exists"
+
     if logtable is None:
         warnings.warn(f"no downloaded information for night {date}")
         data = None
     elif "does not exist for this night" in logtable:
         warnings.warn(f"No observing log for {date}")
         data = None
+    elif message_missing in logtable:
+        warnings.warn(f"No observing log for {date}")
+        data = None
     else:
         data = [l.split() for l in logtable.splitlines()] if logtable is not None else None
             
@@ -215,12 +222,13 @@ def download_completed_log(date, auth=None, store=True,
                    'RA Rate', 'Dec Rate', 'Exptime', 'Filter', 'Observation Status',
                    'Setup Time', 'Exptime']
 
-            
+
     try:
         df = pandas.DataFrame(data, columns=columns)
     except:
-        warnings.warn(f"Column format does not match the completed_log date downloade for {date}")
+        warnings.warn(f"Column format does not match the completed_log date downloaded for {date}")
         print("FORMAT ERROR:", data)
+
         return data
         
     if store:
@@ -427,8 +435,8 @@ def download_qa_log(date, auth=None, summary_values=None, inclcal=True,
                         low_memory=False, index_col=0)
         df['obsdatetime'] = pandas.to_datetime(df['obsdatetime'])
         if "qcomment" in df.columns:
-            df.loc[:,"qcomment"] = df["qcomment"].str.strip()
-            
+            df.loc[:,"qcomment"] = df["qcomment"].astype(str).str.strip()
+
     
     if store:
         df.to_csv( get_log_filepath(date, which="qa"), index=False)
@@ -683,7 +691,7 @@ class CompletedLog( ZTFLog ):
         return self.get_filtered(field=field, pid=pid, fid=fid, startdate=startdate, enddate=enddate, query=query, **kwargs)
     
 
-    def get_fields_stat(self, what="size", perfilter=False, statistic="mean", asdict=False, **kwargs):
+    def get_fields_stat(self, what="size", perfilter=False, statistic="mean", as_dict=False, **kwargs):
         """ 
     
         Parameters
@@ -701,12 +709,12 @@ class CompletedLog( ZTFLog ):
             what pandas statistics should by applied
             = ignored if what='size' =
             
-        asdict: [bool] -optional-
+        as_dict: [bool] -optional-
             if perfilter, the returned value should it be {pid:serie} or multiindex.
             
         Returns
         -------
-        dict or serie. (see asdict)
+        dict or serie. (see as_dict)
         """
         data = self.get_filtered(**kwargs)
         fgroup = data.groupby("field" if not perfilter else ["fid","field"])
@@ -721,19 +729,19 @@ class CompletedLog( ZTFLog ):
         else:
             serieout =  getattr(fgroup[what],statistic)()
             
-        if perfilter and asdict:
+        if perfilter and as_dict:
             return {i:serieout.xs(i) for i in range(1,4)}
         
         return serieout
         
     def get_cadence(self, perfilter=True, statistic="mean", pid=None, fid=None,
-                    field=None, grid=None, asdict=True, **kwargs):
+                    field=None, grid=None, as_dict=True, **kwargs):
         """ 
         **kwargs goes to get_filtered
         """
         return self.get_fields_stat(what="cadence", perfilter=perfilter, statistic=statistic,
                                     field=field, fid=fid, pid=pid, grid=grid, 
-                                    asdict=asdict, **kwargs)
+                                    as_dict=as_dict, **kwargs)
     
         
     def get_programs(self, flatten=False, cleannan=True):
